@@ -58,9 +58,7 @@ recordsManagementMethods <- function(rcon,
                                      record_name, 
                                      new_record_name, 
                                      arm, 
-                                     ..., 
-                                     error_handling, 
-                                     config, 
-                                     api_param){
+                                     ...)
+{
   NULL
 }
