@@ -53,10 +53,8 @@ exportExternalCoding <- function(rcon,
 exportExternalCoding.redcapApiConnection <- function(rcon, 
                                                      fields         = NULL, 
                                                      ..., 
-                                                     batch_size     = 1000, 
-                                                     error_handling = getOption("redcap_error_handling"), 
-                                                     config         = list(), 
-                                                     api_param      = list()){
+                                                     batch_size     = 1000)
+{
   ###################################################################
   # Argument Validation                                          ####
   
@@ -77,20 +75,7 @@ exportExternalCoding.redcapApiConnection <- function(rcon,
                                null.ok = TRUE, 
                                any.missing = FALSE, 
                                add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling,
-                                        choices = c("null", "error"),
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   checkmate::assert_subset(x = fields, 
@@ -125,27 +110,21 @@ exportExternalCoding.redcapApiConnection <- function(rcon,
                  type = "flat", 
                  rawOrLabel = "raw"), 
             vectorToApiBodyList(fields, "fields"))
-  
-  body <- body[lengths(body) > 0]
-  
+
   Code <- 
     if (!is.null(batch_size)){
       .exportRecordsTyped_Batched(rcon = rcon, 
                                   body = body, 
-                                  records = NULL, 
-                                  config = config, 
-                                  api_param = api_param, 
+                                  records = NULL,
                                   csv_delimiter = ",", 
-                                  batch_size = batch_size, 
-                                  error_handling = error_handling)
+                                  batch_size = batch_size,
+                                  ...)
     } else {
       .exportRecordsTyped_Unbatched(rcon = rcon, 
                                     body = body, 
-                                    records = NULL, 
-                                    config = config, 
-                                    api_param = api_param,
-                                    csv_delimiter = ",", 
-                                    error_handling = error_handling)
+                                    records = NULL,
+                                    csv_delimiter = ",",
+                                    ...)
     }
   
   body$rawOrLabel <- "label"
@@ -154,20 +133,16 @@ exportExternalCoding.redcapApiConnection <- function(rcon,
     if (!is.null(batch_size)){
       .exportRecordsTyped_Batched(rcon = rcon, 
                                   body = body, 
-                                  records = NULL, 
-                                  config = config, 
-                                  api_param = api_param, 
+                                  records = NULL,
                                   csv_delimiter = ",", 
-                                  batch_size = batch_size, 
-                                  error_handling = error_handling)
+                                  batch_size = batch_size,
+                                  ...)
     } else {
       .exportRecordsTyped_Unbatched(rcon = rcon, 
                                     body = body, 
                                     records = NULL, 
-                                    config = config, 
-                                    api_param = api_param,
-                                    csv_delimiter = ",", 
-                                    error_handling = error_handling)
+                                    csv_delimiter = ",",
+                                    ...)
     }
   
   External <- vector("list", length(fields))
