@@ -59,10 +59,8 @@
 # dummy function to control the order of arguments in the help file.
 exportFieldNamesArgs <- function(rcon, 
                                  fields, 
-                                 ..., 
-                                 error_handling, 
-                                 config, 
-                                 api_param){
+                                 ...)
+{
   NULL
 }
 
@@ -81,11 +79,8 @@ exportFieldNames <- function(rcon,
 
 exportFieldNames.redcapApiConnection <- function(rcon, 
                                                  fields         = character(0), 
-                                                 ...,
-                                                 error_handling = getOption("redcap_error_handling"), 
-                                                 config         = list(), 
-                                                 api_param      = list()){
- 
+                                                 ...)
+{
   # Argument validation ---------------------------------------------
   coll <- checkmate::makeAssertCollection()
   
@@ -96,20 +91,7 @@ exportFieldNames.redcapApiConnection <- function(rcon,
   checkmate::assert_character(x = fields,
                               max.len = 1,
                               add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling,
-                                        choices = c("null", "error"),
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   if (length(fields) > 0){
@@ -119,26 +101,13 @@ exportFieldNames.redcapApiConnection <- function(rcon,
   }
 
   # Build the Body List ---------------------------------------------
-  body <- list(token = rcon$token, 
-               content = 'exportFieldNames', 
+  body <- list(content = 'exportFieldNames', 
                format = 'csv',
                returnFormat = 'csv', 
                field = fields)
   
-  body <- body[lengths(body) > 0]
-  
   # Make the API Call -----------------------------------------------
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-  
-  if (response$status_code != 200){
-    redcapError(response, 
-                 error_handling = error_handling)
-
-  }
-  
-  as.data.frame(response)
+  as.data.frame(makeApiCall(rcon, body, ...))
 }
 
 # Unexported --------------------------------------------------------
