@@ -66,11 +66,8 @@ exportPdf.redcapApiConnection <- function(rcon,
                                           events         = NULL,
                                           instruments    = NULL, 
                                           all_records    = FALSE, 
-                                          ...,
-                                          error_handling = getOption("redcap_error_handling"), 
-                                          config         = list(), 
-                                          api_param      = list()){
-
+                                          ...)
+{
   if (is.numeric(record)) record <- as.character(record)
     
    ##################################################################
@@ -114,20 +111,7 @@ exportPdf.redcapApiConnection <- function(rcon,
                             len = 1,
                             any.missing = FALSE,
                             add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"),
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   checkmate::assert_directory_exists(x = dir, 
@@ -151,25 +135,17 @@ exportPdf.redcapApiConnection <- function(rcon,
    ##################################################################
   # Make the Body List
   
-  body <- list(token = rcon$token, 
-               content = 'pdf', 
+  body <- list(content = 'pdf', 
                returnFormat = 'csv', 
                allRecords = if (all_records) as.numeric(all_records) else NULL, 
                record = record, 
                event = events, 
                instrument = instruments)
-  
-  body <- body[lengths(body) > 0]
-  
+
    ##################################################################
   # Call the API
   
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-              
-  if (response$status_code != 200) return(redcapError(response, error_handling))
-  
+  response <- makeApiCall(rcon, body, ...)
   filename <- 
     if (all_records)
       paste0(filename, "_all_records.pdf")
