@@ -18,10 +18,7 @@ renameRecord.redcapApiConnection <- function(rcon,
                                              record_name, 
                                              new_record_name, 
                                              arm = NULL, 
-                                             ..., 
-                                             error_handling = getOption("redcap_error_handling"), 
-                                             config         = list(), 
-                                             api_param      = list()){
+                                             ...){
   
   if (is.numeric(record_name)) record_name <- as.character(record_name)
   if (is.numeric(new_record_name)) new_record_name <- as.character(new_record_name)
@@ -48,20 +45,7 @@ renameRecord.redcapApiConnection <- function(rcon,
                               len = 1, 
                               null.ok = TRUE, 
                               add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"), 
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   ###################################################################
@@ -72,21 +56,8 @@ renameRecord.redcapApiConnection <- function(rcon,
                record = record_name, 
                new_record_name = new_record_name, 
                arm = arm)
-  
-  body <- body[lengths(body) > 0]
-  
+
   ###################################################################
   # Call the API                                                 ####
-  
-  response <- makeApiCall(rcon, 
-                          body = c(body, 
-                                   api_param), 
-                          config = config)
-  
-  if (response$status_code != 200){
-    redcapError(response, 
-                error_handling = error_handling)
-  }
-  
-  invisible(as.character(response) == "1")
+  invisible('1' == as.character(makeApiCall(rcon, body, ...)))
 }
